@@ -27,7 +27,7 @@
 #endif
 
 /*
- * profile structure
+ * user context/profile structure
  */
 struct node {
     char *n_name;		/* key                  */
@@ -50,7 +50,7 @@ struct swit {
 extern struct swit anoyes[];	/* standard yes/no switches */
 
 /*
- * messages structure
+ * folder/messages structure
  */
 
 /*
@@ -88,26 +88,42 @@ extern struct swit anoyes[];	/* standard yes/no switches */
  */
 #define	MBITS "\020\01EXISTS\02DELETED\03SELECTED\04NEW\05UNSEEN"
 
+/*
+ * Primary structure of folder/message information
+ */
 struct msgs {
-    int hghmsg;		/* Highest msg in directory     */
-    int nummsg;		/* Actual Number of msgs        */
-    int lowmsg;		/* Lowest msg number            */
-    int curmsg;		/* Number of current msg if any */
-    int lowsel;		/* Lowest selected msg number   */
-    int hghsel;		/* Highest selected msg number  */
-    int numsel;		/* Number of msgs selected      */
-    char *foldpath;	/* Pathname of folder           */
-    int msgflags;	/* Folder status bits           */
+    int lowmsg;		/* Lowest msg number                 */
+    int hghmsg;		/* Highest msg number                */
+    int nummsg;		/* Actual Number of msgs             */
 
-#ifndef	MTR
+    int lowsel;		/* Lowest selected msg number        */
+    int hghsel;		/* Highest selected msg number       */
+    int numsel;		/* Number of msgs selected           */
+
+    int curmsg;		/* Number of current msg if any      */
+    int msgflags;	/* Folder attributes (READONLY, etc) */
+    char *foldpath;	/* Pathname of folder                */
+
+#if 0
+    /* anyone know why this padding was here?  (rc) */
     char pad1[sizeof(int) - sizeof(char)];
-#endif /* not MTR */
+#endif
 
-    char *msgattrs[NUMATTRS + 1]; /* folder attributes          */
-    int attrstats;		  /* public = 0, private = 1    */
-    int	lowoff;			  /* low element in msgstats[]  */
-    int	hghoff;			  /* hgh element in msgstats[]  */
+    /* name of sequences in this folder */
+    char *msgattrs[NUMATTRS + 1];
 
+    /* bit flags for whether sequence is public (0), or private (1) */
+    int attrstats;
+
+    int	lowoff;			  /* low element in msgstats[]   */
+    int	hghoff;			  /* hgh element in msgstats[]   */
+
+    /*
+     * This is an array of integers.  Each integer is a set
+     * of bits flags for a particular message number.  These
+     * bit flags represent general attributes (EXISTS, SELECTED, etc)
+     * as well as track if message is in particular sequence.
+     */
 #ifndef	MTR
     int msgstats[1];		/* msg status */
 #else
@@ -117,28 +133,61 @@ struct msgs {
 };
 
 #ifndef	MTR
-# define MHSIZE(mp,lo,hi)  ((size_t) (sizeof(*mp) + ((hi) + 2) * sizeof(*mp->msgstats)))
+# define MHSIZE(mp,lo,hi)  ((size_t) (sizeof(*mp) + ((hi) + 2) \
+				      * sizeof(*mp->msgstats)))
 #else
 # define MHSIZE(mp,lo,hi)  ((size_t) sizeof(*mp))
-# define MHSIZEX(mp,lo,hi) ((size_t) (((hi) - (lo) + 1) * sizeof(*mp->msgstats)))
+# define MHSIZEX(mp,lo,hi) ((size_t) (((hi) - (lo) + 1) \
+				      * sizeof(*mp->msgstats)))
 #endif
 
+/*
+ * macros for message and sequence manipulation
+ */
+#define does_exist(mp,msgnum)     ((mp)->msgstats[msgnum] & EXISTS)
+#define set_exists(mp,msgnum)     ((mp)->msgstats[msgnum] &= ~EXISTS)
+#define unset_exists(mp,msgnum)   ((mp)->msgstats[msgnum] |= EXISTS)
+
+#define is_selected(mp,msgnum)    ((mp)->msgstats[msgnum] & SELECTED)
+#define unset_selected(mp,msgnum) ((mp)->msgstats[msgnum] &= ~SELECTED)
+#define set_selected(mp,msgnum)   ((mp)->msgstats[msgnum] |= SELECTED)
+
+#define is_unseen(mp,msgnum)      ((mp)->msgstats[msgnum] & UNSEEN)
+#define unset_unseen(mp,msgnum)   ((mp)->msgstats[msgnum] &= ~UNSEEN)
+#define set_unseen(mp,msgnum)     ((mp)->msgstats[msgnum] |= UNSEEN)
+
+#define in_sequence(mp,seqnum,msgnum) \
+           ((mp)->msgstats[msgnum] & (1 << (FFATTRSLOT + seqnum)))
+#define clear_sequence(mp,seqnum,msgnum) \
+           ((mp)->msgstats[msgnum] &= ~(1 << (FFATTRSLOT + seqnum)))
+#define add_sequence(mp,seqnum,msgnum) \
+           ((mp)->msgstats[msgnum] |= (1 << (FFATTRSLOT + seqnum)))
+
+#define is_seq_private(mp,seqnum) \
+           ((mp)->attrstats & (1 << (FFATTRSLOT + seqnum)))
+#define make_seq_public(mp,seqnum) \
+           ((mp)->attrstats &= ~(1 << (FFATTRSLOT + seqnum)))
+#define make_seq_private(mp,seqnum) \
+           ((mp)->attrstats |= (1 << (FFATTRSLOT + seqnum)))
+#define make_all_public(mp) \
+           ((mp)->attrstats = 0)
+
 #define	NULLMP	((struct msgs *) 0)
 
 /*
  * m_getfld() message parsing
  */
 
-#define NAMESZ  128		/* Limit on component name size    */
+#define NAMESZ  128		/* Limit on component name size     */
 
-#define LENERR  (-2)		/* Name too long error from getfld */
-#define FMTERR  (-3)		/* Message Format error            */
-#define FLD      0		/* Field returned                  */
-#define FLDPLUS  1		/* Field " with more to come       */
-#define FLDEOF   2		/* Field " ending at eom           */
-#define BODY     3		/* Body  " with more to come       */
-#define BODYEOF  4		/* Body  " ending at eom           */
-#define FILEEOF  5		/* Reached end of input file       */
+#define LENERR  (-2)		/* Name too long error from getfld  */
+#define FMTERR  (-3)		/* Message Format error             */
+#define FLD      0		/* Field returned                   */
+#define FLDPLUS  1		/* Field returned with more to come */
+#define FLDEOF   2		/* Field returned ending at eom     */
+#define BODY     3		/* Body  returned with more to come */
+#define BODYEOF  4		/* Body  returned ending at eom     */
+#define FILEEOF  5		/* Reached end of input file        */
 
 /*
  * Maildrop styles
@@ -192,6 +241,7 @@ extern struct node *m_defs;	/* profile/context structure  */
  * their values and reloading the various modules, nmh will run
  * on any system.
  */
+extern char *catproc;
 extern char *components;
 extern char *context;
 extern char *current;
@@ -214,6 +264,7 @@ extern char *mh_seq;
 extern char *mhlformat;
 extern char *mhlforward;
 extern char *mhlproc;
+extern char *mhnproc;
 extern char *moreproc;
 extern char *msgprot;
 extern char *mshproc;
