@@ -365,7 +365,7 @@ getm (char *str, char *dfhost, int dftype, int wanthost, char *eresult)
     }
 #endif /* not BERK */
 
-    mp = (struct mailname *) calloc ((unsigned) 1, sizeof(*mp));
+    mp = (struct mailname *) calloc ((size_t) 1, sizeof(*mp));
     if (mp == NULL) {
 	if (eresult)
 	   strcpy (eresult, "insufficient memory to represent address");
