@@ -242,7 +242,7 @@ fmt_compile(char *fstring, struct format **fmt)
      * normal processing.
      */
     i = strlen(fstring)/2 + 1;
-    next_fp = formatvec = (struct format *)calloc ((unsigned) i,
+    next_fp = formatvec = (struct format *)calloc ((size_t) i,
 						   sizeof(struct format));
     if (next_fp == NULL)
 	adios (NULL, "unable to allocate format storage");
@@ -392,7 +392,7 @@ do_name(char *sp, int preprocess)
 	}
 	if (! (cm->c_type & CT_DATE)) {
 	    cm->c_tws = (struct tws *)
-				calloc((unsigned) 1, sizeof *cm->c_tws);
+				calloc((size_t) 1, sizeof *cm->c_tws);
 	    fp->f_type = preprocess;
 	    PUTCOMP(sp);
 	    cm->c_type |= CT_DATE;
