@@ -60,8 +60,7 @@ new_fs (char *form, char *format, char *def)
 	formats[st.st_size] = '\0';
 
 	fclose (fp);
-    }
-    else {
+    } else {
 	formats = getcpy (format ? format : def);
     }
 
@@ -70,17 +69,18 @@ new_fs (char *form, char *format, char *def)
     return formats;
 }
 
+#define	grot(y,z) case y: *dp++ = z; break;
+
 static void
 normalize (char *cp)
 {
     register char *dp;
 
-    for (dp = cp; *cp; cp++)
-	if (*cp != QUOTE)
+    for (dp = cp; *cp; cp++) {
+	if (*cp != QUOTE) {
 	    *dp++ = *cp;
-	else
+	} else {
 	    switch (*++cp) {
-#define	grot(y,z) case y: *dp++ = z; break;
 		grot ('b', '\b');
 		grot ('f', '\f');
 		grot ('n', '\n');
@@ -96,6 +96,8 @@ normalize (char *cp)
 		    *dp++ = *cp;
 		    break;
 	    }
+	}
+    }
 
     *dp = 0;
 }
