@@ -45,6 +45,7 @@ m_draft (char *folder, char *msg, int use, int *isdf)
 
     if (chdir (buffer) == NOTOK)
 	adios (buffer, "unable to change directory to");
+
     if (!(mp = m_gmsg (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
@@ -63,7 +64,7 @@ m_draft (char *folder, char *msg, int use, int *isdf)
 
     m_setcur (mp, mp->lowsel);
     m_sync (mp);
-    m_fmsg (mp);
+    m_fmsg (mp);		/* free folder/message info */
 
     return cp;
 }
