@@ -5,7 +5,7 @@
  * $Id$
  */
 
-#include <h.mh.h>
+#include <h/mh.h>
 
 extern int sys_nerr;
 extern char *sys_errlist[];
