@@ -5,21 +5,21 @@
  * $Id$
  */
 
+#include <h/mh.h>
+
 #define TO_LOWER 040
 #define NO_MASK  000
 
-#include <ctype.h>
-
 
 int
 uprf (char *c1, char *c2)
 {
     register int c, mask;
 
-    if (c1 == 0 || c2 == 0)
-	return(0);         /* XXX */
+    if (!(c1 && c2))
+	return 0;
 
-    while (c = *c2++)
+    while ((c = *c2++))
     {
 #ifdef LOCALE
 	c &= 0xff;
