@@ -162,7 +162,7 @@ process (char *arg, int length, int norm)
 
     (q = &pq)->pq_next = NULL;
     while ((cp = getname (arg))) {
-	if ((p = (struct pqpair *) calloc ((unsigned) 1, sizeof *p)) == NULL)
+	if ((p = (struct pqpair *) calloc ((size_t) 1, sizeof(*p))) == NULL)
 	    adios (NULL, "unable to allocate pqpair memory");
 	if ((mp = getm (cp, NULL, 0, norm, error)) == NULL) {
 	    p->pq_text = getcpy (cp);
