@@ -127,9 +127,8 @@ main (int argc, char **argv)
 
     process ();
 
-    m_replace (pfolder, current_folder);
-    m_update ();
-
+    m_replace (pfolder, current_folder);	/* update current folder   */
+    m_update ();				/* update the context file */
     done (0);
 }
 
@@ -502,8 +501,8 @@ do_child () {
 	    bbfolder, subfolder);
     printf ("[ Type CTRL-D to finish ]\n");
 
-    m_replace (pfolder, bbfolder + 1);
-    m_update ();
+    m_replace (pfolder, bbfolder + 1);	/* update current folder   */
+    m_update ();			/* update the context file */
 
     sprintf (buffer, "=> %s: %s", invo_name, bb->bb_name);
     execlp (shell, buffer, NULL);
