@@ -57,7 +57,7 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    m_foil (NULL);
+    m_foil (NULL);		/* foil search of user profile */
     mts_init (invo_name);
 
     while ((cp = *argp++)) {
