@@ -124,7 +124,7 @@ main (int argc, char **argv)
     for (datep = 0; dates[datep]; datep++)
 	status += process (dates[datep], width);
 
-    m_update ();
+    m_update ();	/* update the context file */
 
     done (status);
 }
