@@ -329,6 +329,8 @@ AddFolder(char *name, int force)
 #endif
 
     nSeq = 0;
+
+    /* read folder and create message structure */
     if (!(mp = m_gmsg(name))) {
 	advise(NULL, "Can't read folder %s.", name);
 	return;
@@ -351,7 +353,7 @@ AddFolder(char *name, int force)
     }
 
     /*
-     * Save information in Folder struct.
+     * Save folder/message information in Folder struct.
      */
     if (nSeq > 0 || force) {
 	AllocFolders(&folders, &nFoldersAlloced, nFolders + 1);
@@ -361,6 +363,8 @@ AddFolder(char *name, int force)
 	f->nSeq = nSeq;
 	f->priority = AssignPriority(f->name);
     }
+
+    m_fmsg (mp);	/* free folder/message structure */
 }
 
 void
