@@ -448,6 +448,8 @@ main (int argc, char **argv)
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
+
+    /* read folder and create message structure */
     if (!(mp = m_gmsg (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
@@ -616,11 +618,11 @@ go_to_it: ;
 				mp->lowsel = msgnum;
 			    if (mp->hghsel == 0 || msgnum > mp->hghsel)
 				mp->hghsel = msgnum;
+			    set_selected (mp, msgnum);
 			    mp->numsel++;
-			    mp->msgstats[msgnum] |= SELECTED;
 			}
 #endif /* TMA */
-			mp->msgstats[msgnum] |= UNSEEN;
+			set_unseen (mp, msgnum);
 			mp->msgflags |= SEQMOD;
 		    }
 		    break;
@@ -714,11 +716,11 @@ go_to_it: ;
 			mp->lowsel = msgnum;
 		    if (mp->hghsel == 0 || mp->hghsel < msgnum)
 			mp->hghsel = msgnum;
+		    set_selected (mp, msgnum);
 		    mp->numsel++;
-		    mp->msgstats[msgnum] |= SELECTED;
 		}
 #endif /* TMA */
-		mp->msgstats[msgnum] |= UNSEEN;
+		set_unseen (mp, msgnum);
 		mp->msgflags |= SEQMOD;
 		continue;
 	}
@@ -782,7 +784,7 @@ go_to_it: ;
     if (msgnum == hghnum)
 	admonish (NULL, "no messages incorporated");
     else {
-	m_replace (pfolder, folder);
+	m_replace (pfolder, folder);	/* update current folder */
 	if (chgflag)
 	    mp->curmsg = hghnum + 1;
 	mp->hghmsg = msgnum;
@@ -811,7 +813,7 @@ go_to_it: ;
 
     m_setvis (mp, 0);
     m_sync (mp);
-    m_update ();
+    m_update ();	/* update the context file */
 
 #ifdef TMA
     if (decflag && mp->numsel > 0) {
@@ -822,7 +824,7 @@ go_to_it: ;
 
 	tmastart (0);
 	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	    if (mp->msgstats[msgnum] & SELECTED && decipher (msgnum) == OK) {
+	    if (is_selected (mp, msgnum) && decipher (msgnum) == OK) {
 		if ((in = fopen (cp = m_name (msgnum), "r")) == NULL) {
 		    admonish (cp, "unable to open message");
 		    free (cp);
