@@ -1,6 +1,6 @@
 
 /*
- * install-mh.c -- initialize the nmh environment
+ * install-mh.c -- initialize the nmh environment of a new user
  *
  * $Id$
  */
@@ -53,12 +53,13 @@ main (int argc, char **argv)
     }
     defpath = concat (mypath, "/", mh_profile, NULL);
 
-    if (stat (defpath, &st) != NOTOK)
+    if (stat (defpath, &st) != NOTOK) {
 	if (autof)
 	    adios (NULL, "invocation error");
 	else
 	    adios (NULL,
 		    "You already have an nmh profile, use an editor to modify it");
+    }
 
     if (!autof && gans ("Do you want help? ", anoyes)) {
 	putchar ('\n');
@@ -78,11 +79,10 @@ main (int argc, char **argv)
 		path = "Mail";
 	    else
 		goto query;
-	}
-	else
+	} else {
 	    goto query;
-    }
-    else {
+	}
+    } else {
 	if (autof)
 	    printf ("I'm going to create the standard nmh path for you.\n");
 	else
@@ -96,8 +96,7 @@ main (int argc, char **argv)
 			anoyes)) {
 		printf ("What is the path?  %s/", mypath);
 		path = geta ();
-	    }
-	    else {
+	    } else {
 		printf ("What is the whole path?  /");
 		path = concat ("/", geta (), NULL);
 	    }
@@ -110,9 +109,9 @@ main (int argc, char **argv)
 	if (autof || gans (cp, anoyes))
 	    if (makedir (path) == 0)
 		adios (NULL, "unable to create %s", path);
-    }
-    else
+    } else {
 	printf ("[Using existing directory]\n");
+    }
 
     np = m_defs = (struct node *) malloc (sizeof *np);
     if (np == NULL)
@@ -122,20 +121,25 @@ main (int argc, char **argv)
     np->n_context = 0;
     np->n_next = NULL;
 
+    /*
+     * If there is a default profile file in the
+     * nmh `etc' directory, then read it also.
+     */
     if ((in = fopen (mh_defaults, "r"))) {
 	m_readefs (&np->n_next, in, mh_defaults, 0);
 	fclose (in);
     }
 
     ctxpath = getcpy (m_maildir (context = "context"));
-    m_replace (pfolder, defalt);
-    m_update ();
+    m_replace (pfolder, defalt);	/* update current folder   */
+    m_update ();			/* update the context file */
 
     if ((out = fopen (defpath, "w")) == NULL)
 	adios (defpath, "unable to write");
-    for (np = m_defs; np; np = np->n_next)
+    for (np = m_defs; np; np = np->n_next) {
 	if (!np->n_context)
 	    fprintf (out, "%s: %s\n", np->n_name, np->n_field);
+    }
     fclose (out);
 
     done (0);
