@@ -1,6 +1,8 @@
 
 /*
- * mark.c -- mark messages
+ * mark.c -- add message(s) to sequences in given folder
+ *        -- delete messages (s) from sequences in given folder
+ *        -- list sequences in given folder
  *
  * $Id$
  */
@@ -124,11 +126,12 @@ main (int argc, char **argv)
 	    msgs[msgp++] = cp;
     }
 
-    if (!addsw && !deletesw && !listsw)
+    if (!addsw && !deletesw && !listsw) {
 	if (seqp)
 	    addsw++;
 	else
 	    listsw++;
+    }
 
     if (!m_find ("path"))
 	free (path ("./", TFOLDER));
@@ -140,11 +143,15 @@ main (int argc, char **argv)
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
+
+    /* read folder and create message structure */
     if (!(mp = m_gmsg (folder)))
 	adios (NULL, "unable to read folder %s", folder);
+
     if (mp->hghmsg == 0)
 	adios (NULL, "no messages in %s", folder);
 
+    /* parse all the message ranges/sequences and set SELECTED */
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    done (1);
@@ -185,7 +192,7 @@ main (int argc, char **argv)
 	    if (zerosw && !m_seqnew (mp, seqs[seqp], publicsw))
 		done (1);
 	    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-		if (mp->msgstats[msgnum] & SELECTED)
+		if (is_selected (mp, msgnum))
 		    if (!m_seqadd (mp, seqs[seqp], msgnum, publicsw))
 			done (1);
 	}
@@ -198,20 +205,18 @@ main (int argc, char **argv)
 			if (!m_seqadd (mp, seqs[seqp], msgnum, publicsw))
 			    done (1);
 	    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-		if (mp->msgstats[msgnum] & SELECTED)
+		if (is_selected (mp, msgnum))
 		    if (!m_seqdel (mp, seqs[seqp], msgnum))
 			done (1);
 	}
 
-    if (listsw) {
-	int bits = FFATTRSLOT;
-
 #define empty(s) ((s) ? (s) : "")
 
+    if (listsw) {
 	if (!seqp) {
 	    for (i = 0; mp->msgattrs[i]; i++)
 		printf ("%s%s: %s\n", mp->msgattrs[i],
-			mp->attrstats & (1 << (bits + i)) ? " (private)" : "",
+			is_seq_private (mp, i) ? " (private)" : "",
 			empty(m_seq(mp, mp->msgattrs[i])));
 	} else {
 	    for (seqp = 0; seqs[seqp]; seqp++)
@@ -222,15 +227,15 @@ main (int argc, char **argv)
 
 	if (debugsw)
 	    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-		if (mp->msgstats[msgnum] & SELECTED)
+		if (is_selected (mp, msgnum))
 		    printf ("%*d: %s\n", DMAXFOLDER, msgnum,
 			sprintb (buf, (unsigned) mp->msgstats[msgnum],
 			    m_seqbits (mp)));
     }
 
-    m_replace (pfolder, folder);
-    m_sync (mp);
-    m_update ();
-
+    m_replace (pfolder, folder);	/* update current folder         */
+    m_sync (mp);			/* synchronize message sequences */
+    m_fmsg (mp);			/* free folder/message structure */
+    m_update ();			/* update the context file       */
     done (0);
 }
