@@ -10,7 +10,8 @@
 
 #include <h/mh.h>
 
-extern char *mhlibdir;		/* NB: this will change soon */
+extern char *mhlibdir;
+extern char *mhetcdir;
 
 char *sbackup = BACKUP_PREFIX;
 char *slink = LINK;
@@ -29,6 +30,44 @@ static struct swit switches[] = {
     { NULL, 0 }
 };
 
+struct proc {
+    char *p_name;
+    char **p_field;
+};
+
+static struct proc procs [] = {
+     { "context",     &context },
+     { "faceproc",    &faceproc },
+     { "fileproc",    &fileproc },
+     { "foldprot",    &foldprot },
+     { "incproc",     &incproc },
+     { "installproc", &installproc  },
+     { "lproc",       &lproc },
+     { "mailproc",    &mailproc },
+     { "mhlproc",     &mhlproc },
+     { "mhnproc",     &mhnproc },
+     { "moreproc",    &moreproc },
+     { "msgprot",     &msgprot },
+     { "mshproc",     &mshproc },
+     { "packproc",    &packproc },
+     { "postproc",    &postproc },
+     { "rmfproc",     &rmfproc },
+     { "rmmproc",     &rmmproc },
+     { "sendproc",    &sendproc },
+     { "showproc",    &showproc },
+     { "slocalproc",  &slocalproc },
+     { "version",     &version },
+     { "vmhproc",     &vmhproc },
+     { "whatnowproc", &whatnowproc },
+     { "whomproc",    &whomproc },
+     { "etcdir",      &mhetcdir },
+     { "libdir",      &mhlibdir },
+     { "sbackup",     &sbackup },
+     { "link",        &slink },
+     { NULL,          NULL },
+};
+
+
 /*
  * static prototypes
  */
@@ -121,40 +160,6 @@ main(int argc, char **argv)
     done (missed);
 }
 
-struct proc {
-    char *p_name;
-    char **p_field;
-};
-
-static struct proc procs [] = {
-     { "context",     &context },
-     { "faceproc",    &faceproc },
-     { "fileproc",    &fileproc },
-     { "foldprot",    &foldprot },
-     { "incproc",     &incproc },
-     { "installproc", &installproc  },
-     { "lproc",       &lproc },
-     { "mailproc",    &mailproc },
-     { "mhlproc",     &mhlproc },
-     { "moreproc",    &moreproc },
-     { "msgprot",     &msgprot },
-     { "mshproc",     &mshproc },
-     { "packproc",    &packproc },
-     { "postproc",    &postproc },
-     { "rmfproc",     &rmfproc },
-     { "rmmproc",     &rmmproc },
-     { "sendproc",    &sendproc },
-     { "showproc",    &showproc },
-     { "slocalproc",  &slocalproc },
-     { "version",     &version },
-     { "vmhproc",     &vmhproc },
-     { "whatnowproc", &whatnowproc },
-     { "whomproc",    &whomproc },
-     { "libdir",      &mhlibdir },
-     { "sbackup",     &sbackup },
-     { "link",        &slink },
-     { NULL,          NULL },
-};
 
 static char *
 p_find(char *str)
