@@ -117,21 +117,25 @@ main (int argc, char **argv)
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to ");
+
+    /* read folder and create message structure */
     if (!(mp = m_gmsg (folder)))
 	adios (NULL, "unable to read folder %s", folder);
+
     if (mp->hghmsg == 0)
 	adios (NULL, "no messages in %s", folder);
 
+    /* parse all the message ranges/sequences and set SELECTED */
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    done (1);
-    m_setseq (mp);
+    m_setseq (mp);	/* set the previous-sequence */
 
     if ((md = mbx_open (file, mbx_style, getuid (), getgid (), m_gmprot ())) == NOTOK)
 	adios (file, "unable to open");
 
     for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	if (mp->msgstats[msgnum] & SELECTED) {
+	if (is_selected(mp, msgnum)) {
 	    if ((fd = open (msgnam = m_name (msgnum), 0)) == NOTOK) {
 		admonish (msgnam, "unable to read message");
 		break;
@@ -144,12 +148,12 @@ main (int argc, char **argv)
 	}
     mbx_close (file, md);
 
-    m_replace (pfolder, folder);
+    m_replace (pfolder, folder);	/* update current folder         */
     if (mp->hghsel != mp->curmsg)
 	m_setcur (mp, mp->lowsel);
     m_sync (mp);
-    m_update ();
-
+    m_fmsg (mp);			/* free folder/message structure */
+    m_update ();			/* update the context file       */
     done (0);
 }
 
