@@ -239,20 +239,18 @@ main (int argc, char **argv)
     if (!(mp = m_gmsg (folder)))
 	adios (NULL, "unable to read folder %s", folder);
 
-#ifdef	BPOP
+#ifdef BPOP
     if (autosw)
 	msh ();
     else
 #endif
-	popi();
 
+    popi();
     pop_quit();
-
-    m_replace (pfolder, folder);
+    m_replace (pfolder, folder);	/* update current folder   */
     m_setvis (mp, 0);
     m_sync (mp);
-    m_update ();
-
+    m_update ();			/* update the context file */
     done (0);
 
     /* NOTREACHED */
@@ -452,7 +450,8 @@ retr_action (char *rsp, int flag)
 
 	    fflush (fp);
 	    if (fstat (fileno (fp), &st) != NOTOK && st.st_size > 0) {
-		mp->msgstats[msgnum] = EXISTS | UNSEEN;
+		mp->msgstats[msgnum] = EXISTS;
+		set_unseen (mp, msgnum);
 		mp->msgflags |= SEQMOD;
 
 		if (ferror (fp))
