@@ -367,7 +367,7 @@ main (int argc, char **argv)
     setlocale(LC_ALL, "");
 #endif
     invo_name = r1bindex (argv[0], '/');
-    m_foil (NULL);
+    m_foil (NULL);		/* foil search of use profile */
     mts_init (invo_name);
 #ifdef	MMDFMTS
 #ifdef	MMDFII
@@ -395,7 +395,7 @@ main (int argc, char **argv)
 		case LIBSW:
 		    if (!(cp = *argp++) || *cp == '-')
 			adios (NULL, "missing argument to %s", argp[-2]);
-		    m_foil (cp);
+		    m_foil (cp);  /* create a minimal context */
 		    continue;
 
 		case ALIASW: 
@@ -1257,8 +1257,7 @@ make_bcc_file (void)
 	fprintf (out, "%s: %s\n%s: multipart/digest; boundary=\"",
 		 VRSN_FIELD, VRSN_VALUE, TYPE_FIELD);
 	fprintf (out, "%s\"\n\n--%s\n\n", prefix, prefix);
-    }
-    else
+    } else
 #endif /* MIME */
 	fprintf (out, "\n------- Blind-Carbon-Copy\n\n");
     fflush (out);
@@ -1273,8 +1272,7 @@ make_bcc_file (void)
 #endif /* MIME */
 	    cpydgst (fd, fileno (out), tmpfil, bccfil);
 	close (fd);
-    }
-    else {
+    } else {
 	vec[0] = r1bindex (mhlproc, '/');
 
 	for (i = 0; (child_id = fork()) == NOTOK && i < 5; i++)
