@@ -1,6 +1,6 @@
 
 /*
- * prompter.c -- prompting editor front-end
+ * prompter.c -- simple prompting editor front-end
  *
  * $Id$
  */
@@ -89,8 +89,8 @@ static jmp_buf sigenv;
  * prototypes
  */
 int getln (char *, int);
-int chrcnv (char *);
-void chrdsp (char *, char);
+static int chrcnv (char *);
+static void chrdsp (char *, char);
 static RETSIGTYPE intrser (int);
 
 
@@ -185,6 +185,7 @@ main (int argc, char **argv)
 	adios (tmpfil, "unable to create");
     chmod (tmpfil, 0600);
 
+    /* Are we changing the kill or erase character? */
     if (killp || erasep) {
 #ifdef HAVE_TERMIOS_H
 	cc_t save_erase, save_kill;
@@ -192,7 +193,7 @@ main (int argc, char **argv)
 	int save_erase, save_kill;
 #endif
 
-	/* get the terminal attributes */
+	/* get the current terminal attributes */
 #ifdef HAVE_TERMIOS_H
 	tcgetattr(0, &tio);
 #else
@@ -204,8 +205,11 @@ main (int argc, char **argv)
 # endif
 #endif
 
+	/* save original kill, erase character for later */
 	save_kill = KILL;
 	save_erase = ERASE;
+
+	/* set new kill, erase character in terminal structure */
 	KILL = killp ? chrcnv (killp) : save_kill;
 	ERASE = erasep ? chrcnv (erasep) : save_erase;
 
@@ -220,12 +224,18 @@ main (int argc, char **argv)
 # endif
 #endif
 
+	/* print out new kill erase characters */
 	chrdsp ("erase", ERASE);
 	chrdsp (", kill", KILL);
 	chrdsp (", intr", INTR);
 	putchar ('\n');
 	fflush (stdout);
 
+	/*
+	 * We set the kill and erase character back to original
+	 * setup in terminal structure so we can easily
+	 * restore it upon exit.
+	 */
 	KILL = save_kill;
 	ERASE = save_erase;
     }
@@ -234,7 +244,7 @@ main (int argc, char **argv)
     SIGNAL2 (SIGINT, intrser);
 
     for (state = FLD;;) {
-	switch (state = m_getfld (state, name, field, sizeof field, in)) {
+	switch (state = m_getfld (state, name, field, sizeof(field), in)) {
 	    case FLD: 
 	    case FLDEOF: 
 	    case FLDPLUS: 
@@ -246,7 +256,7 @@ main (int argc, char **argv)
 		    fprintf (out, "%s:%s", name, field);
 		    while (state == FLDPLUS) {
 			state =
-			    m_getfld (state, name, field, sizeof field, in);
+			    m_getfld (state, name, field, sizeof(field), in);
 			printf ("%s", field);
 			fprintf (out, "%s", field);
 		    }
@@ -254,7 +264,7 @@ main (int argc, char **argv)
 		else {
 		    printf ("%s: ", name);
 		    fflush (stdout);
-		    i = getln (field, sizeof field);
+		    i = getln (field, sizeof(field));
 		    if (i == -1) {
 abort: ;
 			if (killp || erasep) {
@@ -278,7 +288,7 @@ abort: ;
 				putc (' ', out);
 			    fprintf (out, "%s", field);
 			} while (i == 1
-				    && (i = getln (field, sizeof field)) >= 0);
+				    && (i = getln (field, sizeof(field))) >= 0);
 			if (i == -1)
 			    goto abort;
 		    }
@@ -305,7 +315,7 @@ abort: ;
 			printf ("\n--------Enter initial text\n\n");
 			fflush (stdout);
 			for (;;) {
-			    getln (buffer, sizeof buffer);
+			    getln (buffer, sizeof(buffer));
 			    if (doteof && buffer[0] == '.' && buffer[1] == '\n')
 				break;
 			    if (buffer[0] == 0)
@@ -319,7 +329,7 @@ abort: ;
 			if (!rapid && !sigint)
 			    printf ("%s", field);
 		    } while (state == BODY &&
-			    (state = m_getfld (state, name, field, sizeof field, in)));
+			    (state = m_getfld (state, name, field, sizeof(field), in)));
 		    if (prepend || !body)
 			break;
 		    else
@@ -328,7 +338,7 @@ abort: ;
 no_body: ;
 		fflush (stdout);
 		for (;;) {
-		    getln (field, sizeof field);
+		    getln (field, sizeof(field));
 		    if (doteof && field[0] == '.' && field[1] == '\n')
 			break;
 		    if (field[0] == 0)
@@ -351,7 +361,7 @@ no_body: ;
     fclose (out);
     SIGNAL (SIGINT, SIG_IGN);
 
-    if (killp || erasep)
+    if (killp || erasep) {
 #ifdef HAVE_TERMIOS_H
 	 tcsetattr(0, TCSADRAIN, &tio);
 #else
@@ -361,6 +371,7 @@ no_body: ;
 	ioctl (0, TIOCSETN, (char *) &tio);
 # endif
 #endif
+    }
 
     if ((fdi = open (tmpfil, 0)) == NOTOK)
 	adios (tmpfil, "unable to re-open");
@@ -371,8 +382,7 @@ no_body: ;
     close (fdo);
     unlink (tmpfil);
 
-    m_update ();
-
+    m_update ();	/* update the context file */
     done (0);
 }
 
@@ -400,7 +410,7 @@ getln (char *buffer, int n)
 	    return NOTOK;
     }
 
-    for (;;)
+    for (;;) {
 	switch (c = getchar ()) {
 	    case EOF: 
 		clearerr (stdin);
@@ -422,6 +432,7 @@ getln (char *buffer, int n)
 		    *cp++ = c;
 		*cp = 0;
 	}
+    }
 }
 
 
@@ -438,14 +449,14 @@ intrser (int i)
 }
 
 
-int
+static int
 chrcnv (char *cp)
 {
     return (*cp != QUOTE ? *cp : m_atoi (++cp));
 }
 
 
-void
+static void
 chrdsp (char *s, char c)
 {
     printf ("%s ", s);
