@@ -1,6 +1,7 @@
 
 /*
- * refile.c -- file messages away
+ * refile.c -- move or link message(s) from a source folder
+ *          -- into one or more destination folders
  *
  * $Id$
  */
@@ -184,14 +185,15 @@ main (int argc, char **argv)
     if (mp->hghmsg == 0)
 	adios (NULL, "no messages in %s", folder);
 
+    /* parse the message range/sequence/name and set SELECTED */
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    done (1);
-    m_setseq (mp);
+    m_setseq (mp);	/* set the previous-sequence */
 
     opnfolds (folders, foldp);
     for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	if (mp->msgstats[msgnum] & SELECTED) {
+	if (is_selected (mp, msgnum)) {
 	    cp = getcpy (m_name (msgnum));
 	    if (m_file (cp, folders, foldp, prsrvf))
 		done (1);
@@ -207,12 +209,12 @@ main (int argc, char **argv)
 	mp->msgflags |= SEQMOD;
     clsfolds (folders, foldp);
 
-    m_replace (pfolder, folder);
+    m_replace (pfolder, folder);	/* update current folder */
     if (mp->hghsel != mp->curmsg
 	    && (mp->numsel != mp->nummsg || linkf))
 	m_setcur (mp, mp->hghsel);
     m_sync (mp);
-    m_update ();
+    m_update ();	/* update the context file */
 
     if (!linkf)
 	removeit (mp, filep, filevec);
@@ -287,12 +289,12 @@ removeit (struct msgs *mp, int filep, char **files)
 	    if (mp->numsel > MAXARGS - 2)
 		adios (NULL, "more than %d messages for %s exec",
 			MAXARGS - 2, rmmproc);
-	    vec = (char **) calloc ((unsigned) (mp->numsel + 2), sizeof *vec);
+	    vec = (char **) calloc ((size_t) (mp->numsel + 2), sizeof *vec);
 	    if (vec == NULL)
 		adios (NULL, "unable to allocate exec vector");
 	    vecp = 1;
 	    for (i = mp->lowsel; i <= mp->hghsel; i++)
-		if (mp->msgstats[i] & SELECTED)
+		if (is_selected (mp, i))
 		    vec[vecp++] = getcpy (m_name (i));
 	    vec[vecp] = NULL;
 	}
@@ -311,7 +313,7 @@ removeit (struct msgs *mp, int filep, char **files)
     }
     else
 	for (i = mp->lowsel; i <= mp->hghsel; i++)
-	    if (mp->msgstats[i] & SELECTED)
+	    if (is_selected (mp, i))
 		if (unlink (cp = m_name (i)) == NOTOK)
 		    admonish (cp, "unable to unlink");
 }
@@ -342,7 +344,7 @@ m_file (char *msg, struct st_fold *folders, int nfolders, int prsrvf)
 #endif /* notdef */
 		mp->nummsg++;
 	    }
-	    mp->msgstats[msgnum] |= SELECTED;		    
+	    set_selected (mp, msgnum);
 	    if (msgnum > mp->hghmsg)
 		mp->hghmsg = msgnum;
 	}
@@ -355,7 +357,8 @@ m_file (char *msg, struct st_fold *folders, int nfolders, int prsrvf)
 
 	    nmsg = m_name (msgnum = ++mp->hghmsg);
 	    mp->nummsg++;
-	    mp->msgstats[msgnum] |= EXISTS | SELECTED;
+	    mp->msgstats[msgnum] |= EXISTS;
+	    set_selected (mp, msgnum);
 	}
 	if (mp->lowmsg == 0)
 	    mp->lowmsg = msgnum;
