@@ -541,17 +541,18 @@ annoaux (int fd)
     if (debugsw)
 	advise (NULL, "annotate%s with %s: \"%s\"",
 		inplace ? " inplace" : "", annotext, cp);
-    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	if (mp->msgstats[msgnum] & SELECTED) {
+    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++) {
+	if (is_selected(mp, msgnum)) {
 	    if (debugsw)
 		advise (NULL, "annotate message %d", msgnum);
 	    annotate (m_name (msgnum), annotext, cp, inplace, 1);
 	}
+    }
 
     free (cp);
 
 oops: ;
-    m_fmsg (mp);
+    m_fmsg (mp);	/* free folder/message info */
 }
 
 
