@@ -319,7 +319,7 @@ lkopen_dot (char *file, int access)
 	    return fd;
 	} else {
 	    if (stat (lkinfo.curlock, &st) == NOTOK) {
-		if (++i > 5)
+		if (i++ > 5)
 		    return NOTOK;
 		sleep (5);
 	    } else {
