@@ -401,19 +401,15 @@ char *
 getusr (void)
 {
     register char *cp, *np;
+    register struct passwd *pw;
 #ifdef KPOP
     uid_t uid;
 #endif /* KPOP */
-    register struct passwd *pw;
 
     if (username[0])
 	return username;
 
-#ifndef KPOP
-    if ((pw = getpwuid (getuid ())) == NULL
-	    || pw->pw_name == NULL
-	    || *pw->pw_name == NULL) {
-#else /* KPOP */
+#ifdef KPOP
     uid = getuid ();
     if (uid == geteuid () && (cp = getenv ("USER")) != NULL
 	&& (pw = getpwnam (cp)) != NULL)
@@ -421,7 +417,12 @@ getusr (void)
     else if ((pw = getpwuid (uid)) == NULL
 	     || pw->pw_name == NULL
 	     || *pw->pw_name == '\0') {
+#else /* KPOP */
+    if ((pw = getpwuid (getuid ())) == NULL
+	    || pw->pw_name == NULL
+	    || *pw->pw_name == '\0') {
 #endif /* KPOP */
+
 	strcpy (username, "unknown");
 	sprintf (fullname, "The Unknown User-ID (%d)", (int) getuid ());
 	return username;
